@@ -14,7 +14,6 @@ import time
 import cfgparse
 import zope.event
 import threading
-import time
 from sets import Set
 from decorator import synchronized
 from zope.component.interfaces import IFactory
@@ -40,17 +39,22 @@ class ConfigurationService(object):
 
     lock = threading.Lock()
 
-    def __init__(self, reload_after=None, watch=False):
+    def __init__(self, watch=False):
         self._clear()
-        self.reload_after = reload_after # seconds
-        self.last_reload = time.time()
         self.watch = watch # Watch configuration file changes
 
         # start notification service
         self.notify_wm = None
         self.notifier = None
+        if watch and not have_pyinotify:
+            raise RuntimeError('The "pyinotify" module must be installed '
+                               'for using watch=True')
         if self.watch and have_pyinotify:
-            self.notify_mask = EventsCodes.IN_MODIFY | EventsCodes.IN_DELETE | EventsCodes.IN_ATTRIB |  EventsCodes.IN_CREATE | EventsCodes.IN_MOVE_SELF
+            self.notify_mask = (EventsCodes.IN_MODIFY 
+                               | EventsCodes.IN_DELETE 
+                               | EventsCodes.IN_ATTRIB 
+                               | EventsCodes.IN_CREATE 
+                               | EventsCodes.IN_MOVE_SELF)
             self.notify_wm = WatchManager()
             event_handler = NotificationEvent()
             event_handler.setService(self) # needed for callback
@@ -65,7 +69,7 @@ class ConfigurationService(object):
 
     def registerModel(self, filename):
         """ Register a configuration model with the service """
-        filename = os.path.abspath(filename)
+        filename = util.expand_full(filename)
         if not os.path.exists(filename):
             raise IOError('Mode file %s does not exist' % filename)
         LOG.info('register model: %s' % filename)
@@ -75,7 +79,7 @@ class ConfigurationService(object):
         """ Load a configuration file matching one of the registered
             models into the service 
         """
-        filename = os.path.abspath(filename)
+        filename = util.expand_full(filename)
         if not os.path.exists(filename):
             raise IOError('Configuration file %s does not exist' % filename)
         LOG.info('loading configuration: %s' % filename)
@@ -83,7 +87,7 @@ class ConfigurationService(object):
         self.reload()
 
         if self.watch and have_pyinotify:
-            # watch path for events handled by mask.
+            # watch path for events handled by notification mask.
             LOG.info('watching %s' % filename)
             self.notify_wm.add_watch(filename, self.notify_mask)
 
@@ -100,10 +104,8 @@ class ConfigurationService(object):
             for filename in self.configuration_files:
                 self.notify_wm.add_watch(filename, self.notify_mask)
 
-        self.last_reload = time.time()
         zope.event.notify(ConfigurationChangedEvent(self.getConfiguration()))
 
-
     def _reload(self):
         """ Reload models and configuration """
 
@@ -128,10 +130,6 @@ class ConfigurationService(object):
             'name' is either a full dotted name or added to a dotted
              prefix.
         """
-
-        if self.reload_after is not None:
-            if time.time() - self.last_reload > self.reload_after:
-                self.reload()
         OL = util.OptionLookup(self.opts, prefix=prefix)
         return OL.get(name)
 
