@@ -39,7 +39,7 @@ def generateParser(name, LOG=None, parser=None):
 def parseModel(filename, parser, LOG=None):
     """ Parse a model specified as an ini-style configuration file """
 
-    filename = os.path.abspath(filename)
+    filename = expand_full(filename)
 
     if LOG:
         LOG.debug('Processing: %s' % filename)
@@ -103,3 +103,12 @@ class OptionLookup(object):
         if self.prefix and not name.startswith(self.prefix):
             name = '%s.%s' % (self.prefix, name)
         return self.known_opts.has_key(name)
+
+
+def expand_full(filename):
+    """ Expand a file - either to its absolute path
+        or expand a leading environment variable.
+    """
+    if filename.startswith('$'):
+        return os.path.expandvars(filename)
+    return os.path.abspath(filename)
