@@ -9,6 +9,8 @@
 ZCML directives for haufe.hrs.configuration
 """
 
+import os
+
 from zope.interface import Interface
 from zope.schema import TextLine 
 from service_hrs import HRSConfigurationService
@@ -33,10 +35,18 @@ class IConfigurationFile(Interface):
 
 
 def registerModel(_context, configuration):
+    context_dirname = os.path.dirname(_context.info.file)
+    possible_cfg = os.path.join(context_dirname, configuration)
+    if os.path.exists(possible_cfg):
+        configuration = possible_cfg
     HRSConfigurationService.registerModel(configuration)
 
 def registerConfiguration(_context, configuration):
     # str() because cfgparse.add_file performs an explicit check
     # for <str> type
+    context_dirname = os.path.dirname(_context.info.file)
+    possible_cfg = os.path.join(context_dirname, configuration)
+    if os.path.exists(possible_cfg):
+        configuration = possible_cfg
     HRSConfigurationService.loadConfiguration(str(configuration))
 
